==> hilster_theme-3.2.0-py2.py3-none-any.whl: hilster_theme/__init__.py <==
import os

import sphinx_rtd_theme
from hilster_theme import _version as version
import requests
import datetime


def get_versions(product, base_url="https://docs.hilster.io/"):
    """
    Return a list with all versions that have docs online for a given job.

    Args:
        product (str): the name of the product
        base_url (str): the docs base url
    """
    url = f'{base_url}{product}/versions.php'
    session = requests.Session()
    ret = session.get(url)

    assert ret.status_code == 200, "Status is not 200"

    data = ret.json()

    versions = []

    if 'latest' in data:
        del data[data.index('latest')]

    if 'discontinued' in data:
        del data[data.index('discontinued')]

    versions += list(reversed(data))

    return versions


# cache for versions
versions = None


def get_version_tuples(product, base_url="https://docs.hilster.io/"):
    """
    Return a sorted tuple containing all versions and urls for all versions.
    'latest' marks the latest version.

    Args:
        product (str): the name of the product
        base_url (str): the docs base url
    """

    global versions

    if not product:
        # do not return any versions if the product is not set
        # version selection will not appear in generated docs
        return versions

    # cache
    if versions:
        return versions

    try:
        all_versions = get_versions(product, base_url)
    except Exception:
        print("versions for", product, "could not be fetched!")
        all_versions = []

    versions = [('latest', f"{base_url}{product}/latest")]

    for v in all_versions:
        # remove product from version
        slug = v

        if slug.startswith(product):
             slug = slug[len(product) + 1:]

        versions.append((slug, f"{base_url}{product}/{v}"))

    print(f"versions for '{product}':", versions)

    return versions


def get_path():
    """
    Shortcut for users whose theme is next to their conf.py.
    """
    # Theme directory is defined as our parent directory
    return os.path.abspath(os.path.dirname(os.path.dirname(__file__)))


def update_context(app, pagename, templatename, context, doctree):
    context['hilster_theme_version'] = version.__version__
    context['versions'] = get_version_tuples(context['theme_product'])
    context['current_version'] = context['version']
    context['year'] = datetime.datetime.now().year


def setup(app):
    print("=" * 80)
    print("Setup sphinx-rtd-theme")
    sphinx_rtd_theme.setup(app)
    print("done.")
    app.setup_extension("sphinx_copybutton")
    app.connect('html-page-context', update_context)
    return {'version': version.__version__,
            'parallel_read_safe': True}

==> hilster_theme-3.3.0-py2.py3-none-any.whl: hilster_theme/__init__.py <==
import os

import sphinx_rtd_theme
from hilster_theme import _version as version
import requests
import datetime
import re


def get_minor_version(version: str) -> str:
    return re.sub(r"\.\d+$", "", version)


def filter_versions(versions: list[str]) -> tuple[list[str], list[str]]:
    """
    Return a tuple of two lists containing the newest patch release versions
    and a list of outdated versions.
    """
    minor_versions: dict[str, list[str]] = dict()

    print(f"filter versions: {versions}")

    versions = list(filter(lambda x: x.lower() not in ["latest", "discontinued"], versions))
    versions.sort(key=lambda s: list(map(int, s.split("-")[-1].split('.'))))

    # print(f"sorted:   {versions=}")

    for version in versions:
        minor_version = get_minor_version(version)
        # print(f"{version=}; {minor_version=}")

        if minor_version not in minor_versions:
            minor_versions[minor_version] = []

        minor_versions[minor_version].append(version)

    # print(f"{minor_versions=}")

    newest_versions: list[str] = []
    outdated_versions: list[str] = []

    for minor, full_versions in sorted(minor_versions.items()):
        # print(f"{minor=}, {full_versions=}, {full_versions[-1]=}")
        if len(full_versions) > 1:
            for v in full_versions[:-1]:
                print(f"Skip version {v}")
                outdated_versions.append(v)
        newest_versions.append(full_versions[-1])

    newest_versions = list(reversed(newest_versions))

    # print(f"filtered versions: {filtered_versions}")
    return newest_versions, outdated_versions


def get_versions(product, base_url="https://docs.hilster.io/"):
    """
    Return a list with all versions that have docs online for a given job.

    Args:
        product (str): the name of the product
        base_url (str): the docs base url
    """
    url = f'{base_url}{product}/versions.php'
    session = requests.Session()
    ret = session.get(url)

    assert ret.status_code == 200, "Status is not 200"

    data = ret.json()

    versions = filter_versions(data)

    return versions


# cache for versions
versions = None


def get_version_tuples(product, base_url="https://docs.hilster.io/"):
    """
    Return a sorted tuple containing all versions and urls for all versions.
    'latest' marks the latest version.

    Args:
        product (str): the name of the product
        base_url (str): the docs base url
    """

    global versions

    if not product:
        # do not return any versions if the product is not set
        # version selection will not appear in generated docs
        return versions

    # cache
    if versions:
        return versions

    try:
        all_versions, _ = get_versions(product, base_url)
    except Exception:
        print("versions for", product, "could not be fetched!")
        all_versions = []

    print(f"{all_versions=}")

    versions = [('latest', f"{base_url}{product}/latest")]

    for v in all_versions:
        # remove product from version
        slug = v

        if slug.startswith(product):
             slug = slug[len(product) + 1:]

        versions.append((slug, f"{base_url}{product}/{v}"))

    print(f"versions for '{product}':", versions)

    return versions


def get_path():
    """
    Shortcut for users whose theme is next to their conf.py.
    """
    # Theme directory is defined as our parent directory
    return os.path.abspath(os.path.dirname(os.path.dirname(__file__)))


def update_context(app, pagename, templatename, context, doctree):
    context['hilster_theme_version'] = version.__version__
    context['versions'] = get_version_tuples(context['theme_product'])
    context['current_version'] = context['version']
    context['year'] = datetime.datetime.now().year


def setup(app):
    print("=" * 80)
    print("Setup sphinx-rtd-theme")
    sphinx_rtd_theme.setup(app)
    print("done.")
    app.setup_extension("sphinx_copybutton")
    app.connect('html-page-context', update_context)
    return {'version': version.__version__,
            'parallel_read_safe': True}
